/**
 * Driver for TicTacToe.
 * @author Oscar.Nierstrasz@acm.org
 * @version 1.6 1999-02-07
 */
import java.io.*;

public class GameDriver {
	public static void main(String args[]) {
		Player X = new Player('X');
		Player O = new Player('O');
		
		System.out.print("Hi!  Would you like to play TicTacToe (t) or Gomoku (g)?: ");
		
		switch(readChar()) {
		case 't':
			playGame(new TicTacToe(X, O));
			break;
		case 'g':
			playGame(new Gomoku(X, O));
			break;
		default:
			System.out.println("I guess you don't want to play!");
		}
		System.out.println("bye!");
	}

	public static void playGame(BoardGame game) {
		playGame(game, true);
	}
	
	public static char readChar() {
		try {
			BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
			String line = in.readLine();
			if ((line == null) || (line.length() == 0))
				return '\n';
			else
				return line.charAt(0);
		} catch (IOException err) {
			return '\n';
		}
	}
	
	public static void playGame(BoardGame game, boolean verbose) {
		try {
			do {
				if (verbose) {
					System.out.println();
					System.out.println(game);
					System.out.print("Player "
						+ game.currentPlayer().mark() + " moves: ");
				}
				game.update();
			} while(game.notOver());
			if (verbose) {
				System.out.print(game);
				System.out.println("game over -- " + game.winner().name() + " wins!");
			}
		} catch (IOException err) {
			if (verbose)
				System.out.println("game terminated!");
		} catch (Exception err) {
			err.printStackTrace();
			System.exit(1);
		}
	}
}
