import java.io.*;

// import com.mw.Profiler.Profiler;

/**
 * Test Driver for TicTacToe.
 * @author Oscar.Nierstrasz@acm.org
 * @version 1.6 1999-02-07
 */
public class TestDriver {
	// Test output is verbose or quiet?
	private static boolean _verbose = false; // true;

	public static void main(String args[]) {
		/* obsolete/
		Profiler.Init(500, 20);
		Profiler.StartProfiling();
		*/
		doTicTacToeTests();
		doGomokuTests();
		/*
		Profiler.StopProfiling();
		Profiler.Dump("TicTacToe Profile");
		Profiler.Terminate();
		*/
	}
	
	public static void doGomokuTests() {
		System.err.println("Started Gomoku Unit Tests");
		// X wins on diagonal
		testGame(new Gomoku(
					new Player('X', "\naa\n" // nonsense input
									+ "f6\ng5\ne7\nd8\nc9\n"),
					new Player('O', "b2\nh4\nc3\nd4\n")),
					"X", (19*19-9));
		System.err.println("Finished Gomoku Unit Tests");
	}
	
	public static void doTicTacToeTests() {
		System.err.println("Started TicTacToe Unit Tests");
		// X wins on diagonal
		testGame(new TicTacToe(
					new Player('X', "a1\nb2\nc3\n"),
					new Player('O', "b1\nc1\n")),
					"X", 4);

		// no one wins
		testGame(new TicTacToe(
					new Player('X', "b2\na1\nb3\na2\nc1\n"),
					new Player('O', "a3\nc3\nb1\nc2\n")),
					"nobody", 0);

		// O wins on reverse diagonal
		// tries invalid moves
		testGame(new TicTacToe(
					new Player('X', "a1\nb1\n"
									+ "a1\nb1\nb2\nc1\nd0\nxxx\n\n" // invalid moves
									+ "a2\n"),
					new Player('O', "b2\nc1\na3\n")),
					"O", 3);

		// X wins on centre column
		testGame(new TicTacToe(
					new Player('X', "b2\nb1\nb3\n"),
					new Player('O', "a1\n"
									+ "b1\nA0\n" // invalid moves
									+ "a3\n")),
					"X", 4);

		// O wins on top row
		testGame(new TicTacToe(
					new Player('X', "b2\na1\nc1\n"),
					new Player('O',"a3\nc3\nb3\n")),
					"O", 3);

		System.err.println("Finished TicTacToe Unit Tests");
	}

	/**
	 * Run a game with simulated input for X and Y,
	 * and check that the winner is as expected.
	 */
	public static void testGame(
		BoardGame game, String winner, int squaresLeft)
	{
		try {
			game.test();
			
			GameDriver.playGame(game, _verbose);
			
			assert(game.winner().name().equals(winner));
			assert(game.squaresLeft() == squaresLeft);
		} catch (AssertionException err) {
			System.err.println("TestDriver assertion failed in\n" + game);
			err.printStackTrace();
		}
	}

	/**
	 * NB: This version of assert() is static.
	 */
	private static void assert(boolean assertion)
		throws AssertionException
	{
		if (!assertion)
			throw new AssertionException("assertion failed in TestDriver");
	}
}